# -*- coding: utf-8 -*-

# Informations utilisée par l'installeur sous Windows.
# titre : description sommaire du module
# description : description détaillée
# defaut : par défaut, le module est-il installé ou non ?





description = {
"titre":                    "Exercices - Inéquations produits et quotients",
"description":              "Résolution d'inéquations à l'aide de tableaux de signes.",
"groupe":                   "Modules en construction",
"defaut":  True,
}
